#!/usr/bin/env python
#
##############################################################################
### NZBGET POST-PROCESSING SCRIPT                                          ###

# Notification to growl.
#
# This script sends the download notification via growl.
#
# NOTE: This script requires Python to be installed on your system.

##############################################################################
### OPTIONS                                                                ###

# Growl host.
#growlhost=localhost

# Growl port.
#growlport=23053

# Growl password.
#growlpassword=

# Make sticky (None, Success, Error, Both).
#growlerrorsticky=Error

### NZBGET POST-PROCESSING SCRIPT                                          ###
##############################################################################

import os
import sys

import gntp.notifier

import logging
logging.basicConfig(level=logging.ERROR)

POSTPROCESS_SUCCESS=93
POSTPROCESS_ERROR=94
POSTPROCESS_NONE=95

# try to convert to int, if it fails the default will be returned
def tryInt(s, s_default = 0):
    try: return int(s)
    except: return s_default

if os.environ.has_key('NZBOP_VERSION'):
    NZBGetVersion=os.environ['NZBOP_VERSION']
else:
    NZBGetVersion='0'

if NZBGetVersion[0:5] < '11.0':
    print('[ERROR] This script requires NZBGet 11.0 or newer. Please update NZBGet')
    sys.exit(POSTPROCESS_NONE)

required_options = ('NZBPO_GROWLHOST', 'NZBPO_GROWLPORT', 'NZBPO_GROWLPASSWORD', 'NZBPO_GROWLERRORSTICKY')
for optname in required_options:
    if (not os.environ.has_key(optname)):
        print('[ERROR] Option %s is missing in configuration file. Please check script settings' % optname[6:])
        sys.exit(POSTPROCESS_NONE)

message = ""
note_type = "Download Complete"
sticky_note = False
error_sticky = False
success_sticky = False

message = os.environ['NZBPP_NZBNAME']

category = os.environ['NZBPP_CATEGORY']
parstatus = os.environ['NZBPP_PARSTATUS']
unpackstatus = os.environ['NZBPP_UNPACKSTATUS']
usesticky = os.environ['NZBPO_GROWLERRORSTICKY']

if usesticky == "Error":
    error_sticky = True
elif usesticky == "Success":
    success_sticky = True
elif usesticky == "Both":
    error_sticky = True
    success_sticky = True    

if category != "":
    message += " (Category: " + category + ")" 

if parstatus == "1":
    note_type = "Download Error"
    message += "\r\nFailed to repair!"
    if error_sticky:
        sticky_note = True
elif parstatus == "3":
    note_type = "Download Error"
    message += "\r\nRepair is disabled!"
    if error_sticky:
        sticky_note = True

if unpackstatus == "1":
    note_type = "Download Error"
    message += "\r\nUnpack failed!"
    if error_sticky:
        sticky_note = True

if os.environ['NZBOP_UNPACK'] != 'yes':
    note_type = "Download Error"
    message += "\r\nUnpack disabled!"
    if error_sticky:
        sticky_note = True

if success_sticky and note_type != "Download Error":
    sticky_note = True

image_filename = os.path.join(os.path.dirname(os.path.realpath(__file__)),"nzbget.png")

if os.path.isfile(image_filename):
    image = open(image_filename, 'rb').read()
else:
    image = ""        

growl = gntp.notifier.GrowlNotifier(
    applicationName = "NZBGet",
    notifications = ["Download Complete","Download Error"],
    defaultNotifications = ["Download Complete","Download Error"],
    hostname = os.environ['NZBPO_GROWLHOST'],
    password = os.environ['NZBPO_GROWLPASSWORD'],
    port = tryInt(os.environ['NZBPO_GROWLPORT'],23053),
    applicationIcon = image,
)
try:
    growl.register()
    
    # Send message
    growl.notify(
        noteType = note_type,
        title = note_type,
        description = message,
        icon = image,
        sticky = sticky_note,
        priority = 0,
    )
except:
    print('[ERROR] Error sending Growl Notification')
    sys.exit(POSTPROCESS_SUCCESS)

print('[INFO] Growl Notification send')
sys.exit(POSTPROCESS_SUCCESS)